public inbox for newlib-cvs@sourceware.org
help / color / mirror / Atom feed
* [newlib-cygwin] update OpenBSD string functions
@ 2022-01-05 16:20 Corinna Vinschen
  0 siblings, 0 replies; only message in thread
From: Corinna Vinschen @ 2022-01-05 16:20 UTC (permalink / raw)
  To: newlib-cvs

https://sourceware.org/git/gitweb.cgi?p=newlib-cygwin.git;h=8e71066cb27141dccdf4f09639bfb5f2fb3231d6

commit 8e71066cb27141dccdf4f09639bfb5f2fb3231d6
Author: Guilherme Janczak <guilherme.janczak@yandex.com>
Date:   Fri Dec 31 09:31:59 2021 +0000

    update OpenBSD string functions
    
    A lot of the 3rd party code in the string library is around 20 years
    old and has been worked on since.
    I've updated the OpenBSD functions at least.

Diff:
---
 newlib/libc/string/strlcat.c | 88 ++++++++++++++++-----------------------
 newlib/libc/string/strlcpy.c | 77 ++++++++++++++--------------------
 newlib/libc/string/wcslcat.c | 98 +++++++++++++++++++-------------------------
 newlib/libc/string/wcslcpy.c | 89 ++++++++++++++++------------------------
 4 files changed, 144 insertions(+), 208 deletions(-)

diff --git a/newlib/libc/string/strlcat.c b/newlib/libc/string/strlcat.c
index a91c297c5..f35977932 100644
--- a/newlib/libc/string/strlcat.c
+++ b/newlib/libc/string/strlcat.c
@@ -1,73 +1,57 @@
-/*      $OpenBSD: strlcat.c,v 1.8 2001/05/13 15:40:15 deraadt Exp $        */
+/*      $OpenBSD: strlcat.c,v 1.19 2019/01/25 00:19:25 millert Exp $    */
 
 /*
- * Copyright (c) 1998 Todd C. Miller <Todd.Miller@courtesan.com>
- * All rights reserved.
+ * Copyright (c) 1998, 2015 Todd C. Miller <millert@openbsd.org>
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
  *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
- * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
- * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
- * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
- * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+ * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+ * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+ * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#if defined(LIBC_SCCS) && !defined(lint)
-static char *rcsid = "$OpenBSD: strlcat.c,v 1.8 2001/05/13 15:40:15 deraadt Exp $";
-#endif /* LIBC_SCCS and not lint */
-
 #include <sys/types.h>
 #include <string.h>
 
 /*
  * Appends src to string dst of size siz (unlike strncat, siz is the
  * full size of dst, not space left).  At most siz-1 characters
  * will be copied.  Always NUL terminates (unless siz <= strlen(dst)).
  * Returns strlen(src) + MIN(siz, strlen(initial dst)).
  * If retval >= siz, truncation occurred.
  */
 size_t
 strlcat (char *dst,
-	const char *src,
-	size_t siz)
+         const char *src,
+         size_t dsize)
 {
-        register char *d = dst;
-        register const char *s = src;
-        register size_t n = siz;
+        const char *odst = dst;
+        const char *osrc = src;
+        size_t n = dsize;
         size_t dlen;
 
-        /* Find the end of dst and adjust bytes left but don't go past end */
-        while (n-- != 0 && *d != '\0')
-                d++;
-        dlen = d - dst;
-        n = siz - dlen;
-
-        if (n == 0)
-                return(dlen + strlen(s));
-        while (*s != '\0') {
-                if (n != 1) {
-                        *d++ = *s;
+        /* Find the end of dst and adjust bytes left but don't go past end. */
+        while (n-- != 0 && *dst != '\0')
+                dst++;
+        dlen = dst - odst;
+        n = dsize - dlen;
+
+        if (n-- == 0)
+                return(dlen + strlen(src));
+        while (*src != '\0') {
+                if (n != 0) {
+                        *dst++ = *src;
                         n--;
                 }
-                s++;
+                src++;
         }
-        *d = '\0';
+        *dst = '\0';
 
-        return(dlen + (s - src));        /* count does not include NUL */
+        return(dlen + (src - osrc));    /* count does not include NUL */
 }
-
@@ -1,73 +1,57 @@
 
 /*
- * Appends src to string dst of size siz (unlike strncat, siz is the
- * full size of dst, not space left).  At most siz-1 characters
- * will be copied.  Always NUL terminates (unless siz <= strlen(dst)).
- * Returns strlen(src) + MIN(siz, strlen(initial dst)).
- * If retval >= siz, truncation occurred.
+ * Appends src to string dst of size dsize (unlike strncat, dsize is the
+ * full size of dst, not space left).  At most dsize-1 characters
+ * will be copied.  Always NUL terminates (unless dsize <= strlen(dst)).
+ * Returns strlen(src) + MIN(dsize, strlen(initial dst)).
+ * If retval >= dsize, truncation occurred.
  */
 size_t
diff --git a/newlib/libc/string/strlcpy.c b/newlib/libc/string/strlcpy.c
index 63ba31ce9..3df2e4565 100644
--- a/newlib/libc/string/strlcpy.c
+++ b/newlib/libc/string/strlcpy.c
@@ -1,69 +1,52 @@
-/*      $OpenBSD: strlcpy.c,v 1.5 2001/05/13 15:40:16 deraadt Exp $        */
+/*      $OpenBSD: strlcpy.c,v 1.16 2019/01/25 00:19:25 millert Exp $    */
 
 /*
- * Copyright (c) 1998 Todd C. Miller <Todd.Miller@courtesan.com>
- * All rights reserved.
+ * Copyright (c) 1998, 2015 Todd C. Miller <millert@openbsd.org>
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
  *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
- * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
- * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
- * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
- * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+ * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+ * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+ * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#if defined(LIBC_SCCS) && !defined(lint)
-static char *rcsid = "$OpenBSD: strlcpy.c,v 1.5 2001/05/13 15:40:16 deraadt Exp $";
-#endif /* LIBC_SCCS and not lint */
-
 #include <sys/types.h>
 #include <string.h>
 
 /*
  * Copy src to string dst of size siz.  At most siz-1 characters
  * will be copied.  Always NUL terminates (unless siz == 0).
  * Returns strlen(src); if retval >= siz, truncation occurred.
  */
 size_t
 strlcpy (char *dst,
-	const char *src,
-	size_t siz)
+        const char *src,
+        size_t dsize)
 {
-        register char *d = dst;
-        register const char *s = src;
-        register size_t n = siz;
+        const char *osrc = src;
+        size_t nleft = dsize;
 
-        /* Copy as many bytes as will fit */
-        if (n != 0 && --n != 0) {
-                do {
-                        if ((*d++ = *s++) == 0)
+        /* Copy as many bytes as will fit. */
+        if (nleft != 0) {
+                while (--nleft != 0) {
+                        if ((*dst++ = *src++) == '\0')
                                 break;
-                } while (--n != 0);
+                }
         }
 
-        /* Not enough room in dst, add NUL and traverse rest of src */
-        if (n == 0) {
-                if (siz != 0)
-                        *d = '\0';                /* NUL-terminate dst */
-                while (*s++)
+        /* Not enough room in dst, add NUL and traverse rest of src. */
+        if (nleft == 0) {
+                if (dsize != 0)
+                        *dst = '\0';            /* NUL-terminate dst */
+                while (*src++)
                         ;
         }
 
-        return(s - src - 1);        /* count does not include NUL */
+        return(src - osrc - 1); /* count does not include NUL */
 }
-
@@ -1,69 +1,52 @@
 
 /*
- * Copy src to string dst of size siz.  At most siz-1 characters
- * will be copied.  Always NUL terminates (unless siz == 0).
- * Returns strlen(src); if retval >= siz, truncation occurred.
+ * Copy string src to buffer dst of size dsize.  At most dsize-1
+ * chars will be copied.  Always NUL terminates (unless dsize == 0).
+ * Returns strlen(src); if retval >= dsize, truncation occurred.
  */
 size_t
diff --git a/newlib/libc/string/wcslcat.c b/newlib/libc/string/wcslcat.c
index 189a710bd..18890132d 100644
--- a/newlib/libc/string/wcslcat.c
+++ b/newlib/libc/string/wcslcat.c
@@ -13,7 +13,7 @@ DESCRIPTION
 	including the terminating null wide-character code.  A terminating
 	null wide character is always added unless <[siz]> is 0.  Thus,
 	the maximum number of wide characters that can be appended from
-	<[src]> is <[siz]> - 1. If copying takes place between objects 
+	<[src]> is <[siz]> - 1. If copying takes place between objects
 	that overlap, the behaviour is undefined.
 
 RETURNS
@@ -27,74 +27,60 @@ PORTABILITY
 No supporting OS subroutines are required.
 */
 
-/*	$NetBSD: wcslcat.c,v 1.1 2000/12/23 23:14:36 itojun Exp $	*/
-/*	from OpenBSD: strlcat.c,v 1.3 2000/11/24 11:10:02 itojun Exp 	*/
+/*      $OpenBSD: wcslcat.c,v 1.7 2019/01/25 00:19:25 millert Exp $     */
 
 /*
- * Copyright (c) 1998 Todd C. Miller <Todd.Miller@courtesan.com>
- * All rights reserved.
+ * Copyright (c) 1998, 2015 Todd C. Miller <millert@openbsd.org>
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
  *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
- * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
- * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
- * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
- * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+ * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+ * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+ * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include <_ansi.h>
+#include <sys/types.h>
 #include <wchar.h>
 
 /*
  * Appends src to string dst of size siz (unlike wcsncat, siz is the
  * full size of dst, not space left).  At most siz-1 characters
  * will be copied.  Always NUL terminates (unless siz == 0).
  * Returns wcslen(initial dst) + wcslen(src); if retval >= siz,
  * truncation occurred.
  */
 size_t
-wcslcat (wchar_t * dst,
-	const wchar_t * src,
-	size_t siz)
+wcslcat (wchar_t *dst,
+        const wchar_t *src,
+        size_t dsize)
 {
-  wchar_t *d = dst;
-  const wchar_t *s = src;
-  size_t n = siz;
-  size_t dlen;
+        const wchar_t *odst = dst;
+        const wchar_t *osrc = src;
+        size_t n = dsize;
+        size_t dlen;
 
-  /* Find the end of dst and adjust bytes left but don't go past end */
-  while (*d != '\0' && n-- != 0)
-    d++;
-  dlen = d - dst;
-  n = siz - dlen;
+        /* Find the end of dst and adjust bytes left but don't go past end. */
+        while (n-- != 0 && *dst != L'\0')
+                dst++;
+        dlen = dst - odst;
+        n = dsize - dlen;
 
-  if (n == 0)
-    return (dlen + wcslen (s));
-  while (*s != '\0')
-    {
-      if (n != 1)
-	{
-	  *d++ = *s;
-	  n--;
-	}
-      s++;
-    }
-  *d = '\0';
+        if (n-- == 0)
+                return(dlen + wcslen(src));
+        while (*src != L'\0') {
+                if (n != 0) {
+                        *dst++ = *src;
+                        n--;
+                }
+                src++;
+        }
+        *dst = L'\0';
 
-  return (dlen + (s - src));	/* count does not include NUL */
+        return(dlen + (src - osrc));    /* count does not include NUL */
 }
@@ -27,74 +27,60 @@ PORTABILITY
 
 /*
- * Appends src to string dst of size siz (unlike wcsncat, siz is the
- * full size of dst, not space left).  At most siz-1 characters
- * will be copied.  Always NUL terminates (unless siz == 0).
- * Returns wcslen(initial dst) + wcslen(src); if retval >= siz,
- * truncation occurred.
+ * Appends src to string dst of size dsize (unlike strncat, dsize is the
+ * full size of dst, not space left).  At most dsize-1 characters
+ * will be copied.  Always NUL terminates (unless dsize <= wcslen(dst)).
+ * Returns wcslen(src) + MIN(dsize, wcslen(initial dst)).
+ * If retval >= siz, truncation occurred.
  */
 size_t
diff --git a/newlib/libc/string/wcslcpy.c b/newlib/libc/string/wcslcpy.c
index 3d688a943..40f0c77b6 100644
--- a/newlib/libc/string/wcslcpy.c
+++ b/newlib/libc/string/wcslcpy.c
@@ -23,72 +23,55 @@ PORTABILITY
 No supporting OS subroutines are required.
 */
 
-/*	$NetBSD: wcslcpy.c,v 1.1 2000/12/23 23:14:36 itojun Exp $	*/
-/*	from OpenBSD: strlcpy.c,v 1.4 1999/05/01 18:56:41 millert Exp 	*/
+/*      $OpenBSD: wcslcpy.c,v 1.8 2019/01/25 00:19:25 millert Exp $     */
 
 /*
- * Copyright (c) 1998 Todd C. Miller <Todd.Miller@courtesan.com>
- * All rights reserved.
+ * Copyright (c) 1998, 2015 Todd C. Miller <millert@openbsd.org>
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
  *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
- * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
- * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
- * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
- * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+ * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+ * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+ * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include <_ansi.h>
+#include <sys/types.h>
 #include <wchar.h>
 
 /*
  * Copy src to string dst of size siz.  At most siz-1 characters
  * will be copied.  Always NUL terminates (unless siz == 0).
  * Returns wcslen(src); if retval >= siz, truncation occurred.
  */
 size_t
-wcslcpy (wchar_t * dst,
-	const wchar_t * src,
-	size_t siz)
+wcslcpy (wchar_t *dst,
+        const wchar_t *src,
+        size_t dsize)
 {
-  wchar_t *d = dst;
-  const wchar_t *s = src;
-  size_t n = siz;
+        const wchar_t *osrc = src;
+        size_t nleft = dsize;
 
-  /* Copy as many bytes as will fit */
-  if (n != 0 && --n != 0)
-    {
-      do
-	{
-	  if ((*d++ = *s++) == 0)
-	    break;
-	}
-      while (--n != 0);
-    }
+        /* Copy as many bytes as will fit. */
+        if (nleft != 0) {
+                while (--nleft != 0) {
+                        if ((*dst++ = *src++) == L'\0')
+                                break;
+                }
+        }
 
-  /* Not enough room in dst, add NUL and traverse rest of src */
-  if (n == 0)
-    {
-      if (siz != 0)
-	*d = '\0';		/* NUL-terminate dst */
-      while (*s++)
-	;
-    }
+        /* Not enough room in dst, add NUL and traverse rest of src. */
+        if (nleft == 0) {
+                if (dsize != 0)
+                        *dst = L'\0';           /* NUL-terminate dst */
+                while (*src++)
+                        ;
+        }
 
-  return (s - src - 1);		/* count does not include NUL */
+        return(src - osrc - 1); /* count does not include NUL */
 }


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-01-05 16:20 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -23,72 +23,55 @@ PORTABILITY
 
 /*
- * Copy src to string dst of size siz.  At most siz-1 characters
- * will be copied.  Always NUL terminates (unless siz == 0).
- * Returns wcslen(src); if retval >= siz, truncation occurred.
+ * Copy string src to buffer dst of size dsize.  At most dsize-1
+ * chars will be copied.  Always NUL terminates (unless dsize == 0).
+ * Returns wcslen(src); if retval >= dsize, truncation occurred.
  */
 size_t
2022-01-05 16:20 [newlib-cygwin] update OpenBSD string functions Corinna Vinschen

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).